.. _integration_test_report_itest_report_log_links_multisuite:

=============================================================
Integration Test Report for itest_report_log_links_multisuite
=============================================================

The log file that contains details about the executed test cases can be found `here <itest_log.html>`_.

.. contents:: `Contents`
    :depth: 2
    :local:


Test Cases
==========

.. item:: REPORT_ITEST-READ_PRODUCT_ID_1 Test report for ITEST-READ_PRODUCT_ID_1
    :passes: ITEST-READ_PRODUCT_ID_1
    :ext_robotframeworklog: itest_log.html:s1-s1-t1

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_2 Test report for ITEST-READ_PRODUCT_ID_2
    :passes: ITEST-READ_PRODUCT_ID_2
    :ext_robotframeworklog: itest_log.html:s1-s1-t2

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_3 Test report for ITEST-READ_PRODUCT_ID_3
    :passes: ITEST-READ_PRODUCT_ID_3
    :ext_robotframeworklog: itest_log.html:s1-s1-t3

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_4 Test report for ITEST-READ_PRODUCT_ID_4
    :passes: ITEST-READ_PRODUCT_ID_4
    :ext_robotframeworklog: itest_log.html:s1-s1-t4

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_5 Test report for ITEST-READ_PRODUCT_ID_5
    :passes: ITEST-READ_PRODUCT_ID_5
    :ext_robotframeworklog: itest_log.html:s1-s1-t5

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_6 Test report for ITEST-READ_PRODUCT_ID_6
    :passes: ITEST-READ_PRODUCT_ID_6
    :ext_robotframeworklog: itest_log.html:s1-s1-t6

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_7 Test report for ITEST-READ_PRODUCT_ID_7
    :passes: ITEST-READ_PRODUCT_ID_7
    :ext_robotframeworklog: itest_log.html:s1-s1-t7

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_8 Test report for ITEST-READ_PRODUCT_ID_8
    :passes: ITEST-READ_PRODUCT_ID_8
    :ext_robotframeworklog: itest_log.html:s1-s1-t8

    Test result: Pass

.. item:: REPORT_ITEST-READ_PRODUCT_ID_9 Test report for ITEST-READ_PRODUCT_ID_9
    :passes: ITEST-READ_PRODUCT_ID_9
    :ext_robotframeworklog: itest_log.html:s1-s1-t9

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_1 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_1
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_1
    :ext_robotframeworklog: itest_log.html:s1-s2-t1

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_2 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_2
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_2
    :ext_robotframeworklog: itest_log.html:s1-s2-t2

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_3 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_3
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_3
    :ext_robotframeworklog: itest_log.html:s1-s2-t3

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_4 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_4
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_4
    :ext_robotframeworklog: itest_log.html:s1-s2-t4

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_5 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_5
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_5
    :ext_robotframeworklog: itest_log.html:s1-s2-t5

    Test result: Pass

.. item:: REPORT_ITEST-READ_MLX_DEVICE_PROJECT_ID_6 Test report for ITEST-READ_MLX_DEVICE_PROJECT_ID_6
    :passes: ITEST-READ_MLX_DEVICE_PROJECT_ID_6
    :ext_robotframeworklog: itest_log.html:s1-s2-t6

    Test result: Pass

Traceability Matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these integration test reports to integration test cases
    :source: REPORT_ITEST-
    :target: ITEST-
    :sourcetitle: Integration test report
    :targettitle: Integration test specification
    :type: fails passes
    :stats:
    :group: top
    :nocaptions:
